Module git

Module git 

Git primitives for Cursus.

Provides the Git trait so that code performing git operations can be backed by different implementations — local command-line git, remote forge APIs, etc.

GitWorkdir is the production implementation that delegates to the git binary via crate::command::CommandRunner.

Structs

GitWorkdir
A git working directory paired with a command runner.
SignedCommitGit
A Git decorator that produces Verified commits via the GitHub Git Data API.

Traits

Git
Abstracts git operations for testability and extensibility.

Functions

find_workdir
Finds the git working directory by walking up from the given path.